==> owncloud-6.0.4.tgz: owncloud/settings/l10n/ka_GE.php <==
<?php
$TRANSLATIONS = array(
"Unable to load list from App Store" => "აპლიკაციების სია ვერ ჩამოიტვირთა App Store",
"Authentication error" => "ავთენტიფიკაციის შეცდომა",
"Group already exists" => "ჯგუფი უკვე არსებობს",
"Unable to add group" => "ჯგუფის დამატება ვერ მოხერხდა",
"Email saved" => "იმეილი შენახულია",
"Invalid email" => "არასწორი იმეილი",
"Unable to delete group" => "ჯგუფის წაშლა ვერ მოხერხდა",
"Unable to delete user" => "მომხმარებლის წაშლა ვერ მოხერხდა",
"Language changed" => "ენა შეცვლილია",
"Invalid request" => "არასწორი მოთხოვნა",
"Admins can't remove themself from the admin group" => "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
"Unable to add user to group %s" => "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
"Unable to remove user from group %s" => "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
"Couldn't update app." => "ვერ მოხერხდა აპლიკაციის განახლება.",
"Update to {appversion}" => "განაახლე {appversion}–მდე",
"Disable" => "გამორთვა",
"Enable" => "ჩართვა",
"Please wait...." => "დაიცადეთ....",
"Updating...." => "მიმდინარეობს განახლება....",
"Error while updating app" => "შეცდომა აპლიკაციის განახლების დროს",
"Error" => "შეცდომა",
"Update" => "განახლება",
"Updated" => "განახლებულია",
"Saving..." => "შენახვა...",
"deleted" => "წაშლილი",
"undo" => "დაბრუნება",
"Unable to remove user" => "მომხმარებლის წაშლა ვერ მოხერხდა",
"Groups" => "ჯგუფები",
"Group Admin" => "ჯგუფის ადმინისტრატორი",
"Delete" => "წაშლა",
"add group" => "ჯგუფის დამატება",
"A valid username must be provided" => "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
"Error creating user" => "შეცდომა მომხმარებლის შექმნისას",
"A valid password must be provided" => "უნდა მიუთითოთ არსებული პაროლი",
"__language_name__" => "__language_name__",
"Security Warning" => "უსაფრთხოების გაფრთხილება",
"Setup Warning" => "გაფრთხილება დაყენებისას",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "თქვენი web სერვერი არ არის კონფიგურირებული ფაილ სინქრონიზაციისთვის, რადგან WebDAV ინტერფეისი შეიძლება იყოს გატეხილი.",
"Module 'fileinfo' missing" => "მოდული 'fileinfo'  არ არსებობს",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
"Locale not working" => "ლოკალიზაცია არ მუშაობს",
"Internet connection not working" => "ინტერნეტ კავშირი არ მუშაობს",
"Cron" => "Cron–ი",
"Execute one task with each page loaded" => "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
"Sharing" => "გაზიარება",
"Enable Share API" => "Share API–ის ჩართვა",
"Allow apps to use the Share API" => "დაუშვი აპლიკაციების უფლება  Share API –ზე",
"Allow links" => "ლინკების დაშვება",
"Allow users to share items to the public with links" => "მიეცი მომხმარებლებს უფლება რომ გააზიაროს ელემენტები საჯაროდ ლინკებით",
"Allow resharing" => "გადაზიარების დაშვება",
"Allow users to share items shared with them again" => "მიეცით მომხმარებლებს უფლება რომ გააზიაროს მისთვის გაზიარებული",
"Allow users to share with anyone" => "მიეცით უფლება მომხმარებლებს გააზიაროს ყველასთვის",
"Allow users to only share with users in their groups" => "მიეცით უფლება მომხმარებლებს რომ გააზიაროს მხოლოდ თავიანთი ჯგუფისთვის",
"Security" => "უსაფრთხოება",
"Enforce HTTPS" => "HTTPS–ის ჩართვა",
"Log" => "ლოგი",
"Log level" => "ლოგირების დონე",
"More" => "უფრო მეტი",
"Less" => "უფრო ნაკლები",
"Version" => "ვერსია",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "წარმოებულია <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>–ის მიერ. <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a>  ვრცელდება <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> ლიცენზიის ფარგლებში.",
"Add your App" => "დაამატე შენი აპლიკაცია",
"More Apps" => "უფრო მეტი აპლიკაციები",
"Select an App" => "აირჩიეთ აპლიკაცია",
"See application page at apps.owncloud.com" => "ნახეთ აპლიკაციის გვერდი apps.owncloud.com –ზე",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-ლიცენსირებულია <span class=\"author\"></span>",
"User Documentation" => "მომხმარებლის დოკუმენტაცია",
"Administrator Documentation" => "ადმინისტრატორის დოკუმენტაცია",
"Online Documentation" => "ონლაინ დოკუმენტაცია",
"Forum" => "ფორუმი",
"Bugtracker" => "ბაგთრექერი",
"Commercial Support" => "კომერციული მხარდაჭერა",
"Get the apps to sync your files" => "აპლიკაცია ფაილების სინქრონიზაციისთვის",
"Show First Run Wizard again" => "მაჩვენე თავიდან გაშვებული ვიზარდი",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "თქვენ გამოყენებული გაქვთ <strong>%s</strong> –ი –<strong>%s</strong>–დან",
"Password" => "პაროლი",
"Your password was changed" => "თქვენი პაროლი შეიცვალა",
"Unable to change your password" => "თქვენი პაროლი არ შეიცვალა",
"Current password" => "მიმდინარე პაროლი",
"New password" => "ახალი პაროლი",
"Change password" => "პაროლის შეცვლა",
"Email" => "იმეილი",
"Your email address" => "თქვენი იმეილ მისამართი",
"Fill in an email address to enable password recovery" => "შეავსეთ იმეილ მისამართის ველი პაროლის აღსადგენად",
"Language" => "ენა",
"Help translate" => "თარგმნის დახმარება",
"WebDAV" => "WebDAV",
"Encryption" => "ენკრიპცია",
"Login Name" => "მომხმარებლის სახელი",
"Create" => "შექმნა",
"Default Storage" => "საწყისი საცავი",
"Unlimited" => "ულიმიტო",
"Other" => "სხვა",
"Username" => "მომხმარებლის სახელი",
"Storage" => "საცავი",
"set new password" => "დააყენეთ ახალი პაროლი",
"Default" => "საწყისი პარამეტრები"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-7.0.4.tgz: owncloud/settings/l10n/ka_GE.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "იმეილი გაიგზავნა",
"Encryption" => "ენკრიპცია",
"Unable to load list from App Store" => "აპლიკაციების სია ვერ ჩამოიტვირთა App Store",
"Authentication error" => "ავთენტიფიკაციის შეცდომა",
"Group already exists" => "ჯგუფი უკვე არსებობს",
"Unable to add group" => "ჯგუფის დამატება ვერ მოხერხდა",
"Email saved" => "იმეილი შენახულია",
"Invalid email" => "არასწორი იმეილი",
"Unable to delete group" => "ჯგუფის წაშლა ვერ მოხერხდა",
"Unable to delete user" => "მომხმარებლის წაშლა ვერ მოხერხდა",
"Language changed" => "ენა შეცვლილია",
"Invalid request" => "არასწორი მოთხოვნა",
"Admins can't remove themself from the admin group" => "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
"Unable to add user to group %s" => "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
"Unable to remove user from group %s" => "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
"Couldn't update app." => "ვერ მოხერხდა აპლიკაციის განახლება.",
"User Documentation" => "მომხმარებლის დოკუმენტაცია",
"Update to {appversion}" => "განაახლე {appversion}–მდე",
"Disable" => "გამორთვა",
"Enable" => "ჩართვა",
"Please wait...." => "დაიცადეთ....",
"Updating...." => "მიმდინარეობს განახლება....",
"Error while updating app" => "შეცდომა აპლიკაციის განახლების დროს",
"Error" => "შეცდომა",
"Update" => "განახლება",
"Updated" => "განახლებულია",
"undo" => "დაბრუნება",
"Groups" => "ჯგუფები",
"Group Admin" => "ჯგუფის ადმინისტრატორი",
"Delete" => "წაშლა",
"never" => "არასდროს",
"add group" => "ჯგუფის დამატება",
"A valid username must be provided" => "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
"Error creating user" => "შეცდომა მომხმარებლის შექმნისას",
"A valid password must be provided" => "უნდა მიუთითოთ არსებული პაროლი",
"__language_name__" => "__language_name__",
"None" => "არა",
"Login" => "ლოგინი",
"Security Warning" => "უსაფრთხოების გაფრთხილება",
"Setup Warning" => "გაფრთხილება დაყენებისას",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "თქვენი web სერვერი არ არის კონფიგურირებული ფაილ სინქრონიზაციისთვის, რადგან WebDAV ინტერფეისი შეიძლება იყოს გატეხილი.",
"Module 'fileinfo' missing" => "მოდული 'fileinfo'  არ არსებობს",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
"Locale not working" => "ლოკალიზაცია არ მუშაობს",
"Internet connection not working" => "ინტერნეტ კავშირი არ მუშაობს",
"Cron" => "Cron–ი",
"Execute one task with each page loaded" => "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
"Sharing" => "გაზიარება",
"Allow apps to use the Share API" => "დაუშვი აპლიკაციების უფლება  Share API –ზე",
"Allow resharing" => "გადაზიარების დაშვება",
"Security" => "უსაფრთხოება",
"Enforce HTTPS" => "HTTPS–ის ჩართვა",
"Server address" => "სერვერის მისამართი",
"Port" => "პორტი",
"Credentials" => "იუზერ/პაროლი",
"Log" => "ლოგი",
"Log level" => "ლოგირების დონე",
"More" => "უფრო მეტი",
"Less" => "უფრო ნაკლები",
"Version" => "ვერსია",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "წარმოებულია <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>–ის მიერ. <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a>  ვრცელდება <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> ლიცენზიის ფარგლებში.",
"Add your App" => "დაამატე შენი აპლიკაცია",
"More Apps" => "უფრო მეტი აპლიკაციები",
"Select an App" => "აირჩიეთ აპლიკაცია",
"See application page at apps.owncloud.com" => "ნახეთ აპლიკაციის გვერდი apps.owncloud.com –ზე",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-ლიცენსირებულია <span class=\"author\"></span>",
"All" => "ყველა",
"Administrator Documentation" => "ადმინისტრატორის დოკუმენტაცია",
"Online Documentation" => "ონლაინ დოკუმენტაცია",
"Forum" => "ფორუმი",
"Bugtracker" => "ბაგთრექერი",
"Commercial Support" => "კომერციული მხარდაჭერა",
"Get the apps to sync your files" => "აპლიკაცია ფაილების სინქრონიზაციისთვის",
"Show First Run Wizard again" => "მაჩვენე თავიდან გაშვებული ვიზარდი",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "თქვენ გამოყენებული გაქვთ <strong>%s</strong> –ი –<strong>%s<strong>–დან",
"Password" => "პაროლი",
"Your password was changed" => "თქვენი პაროლი შეიცვალა",
"Unable to change your password" => "თქვენი პაროლი არ შეიცვალა",
"Current password" => "მიმდინარე პაროლი",
"New password" => "ახალი პაროლი",
"Change password" => "პაროლის შეცვლა",
"Email" => "იმეილი",
"Your email address" => "თქვენი იმეილ მისამართი",
"Cancel" => "უარყოფა",
"Language" => "ენა",
"Help translate" => "თარგმნის დახმარება",
"Login Name" => "მომხმარებლის სახელი",
"Create" => "შექმნა",
"Default Quota" => "საწყისი ქვოტა",
"Unlimited" => "ულიმიტო",
"Other" => "სხვა",
"Username" => "მომხმარებლის სახელი",
"Quota" => "ქვოტა",
"set new password" => "დააყენეთ ახალი პაროლი",
"Default" => "საწყისი პარამეტრები"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
